@@ -7,58 +7,70 @@ import base
 available_apis = []
 
 #apis in order of "awesomeness" 
-
-#attempt to import minidom first
 try:
     import xml.dom.minidom
     import minidom
     #define it's api
-    gxml = minidom.minidom
+    class gxml(minidom.minidom):
+        __api__ = minidom.minidom
     #list it as an available api
-    Element = minidom.Element
     to_string = minidom.to_string
-    from_string = minidom.from_string
     available_apis.append(['minidom',minidom])
+    Element = minidom.Element
+
 except ImportError:
     pass
 
 try:
    import elementtree
    import elemtree
-   gxml = elemtree.elemtree
-   Element = elemtree.Element
+   
+   class gxml(elemtree.elemtree):
+      __api__ = elemtree.elemtree
+
    to_string = elemtree.to_string
-   from_string = elemtree.from_string
+
    available_apis.append(['elementtree',elemtree])
+
+   Element = elemtree.Element
+
 except ImportError:
    pass
 
+
+
 if not gxml:
     raise ImportError("No Supported XML library found!")
 
+def from_string(xml_str):
+    t = gxml()
+    t.from_string(xml_str)
+    return t
+
+XML = from_string
+
 def clone(node):
     t = gxml()
     return t.from_string(to_string(node))
 
-def preference(pref_list):
-    global gxml, Element, to_string
-    
-    if not isinstance(pref_list,list):
-        pref_list = [pref_list]
-
-    """Selects a gxml sub-api by preference."""
-    for preferred in pref_list:
-        for name, api in available_apis:
-            if preferred == name:
-                return api
-    return gxml
-
 def is_element(element):
     return hasattr(element,'node') or isinstance(element,base.node)    
 
-            
+def SubElement(parent, child_tag):
+    """Create a SubElement of child_tag and append it to the parent."""
+    #create the child
+    t = Element(child_tag)
+    #append it to the parent
+    parent.append(t)
+    #return the child
+    return t
+
+def parse(file_like):
+    t = gxml()
+    return t.parse(file_like)
+
+
 
 
         
 
-    
