@@ -1,27 +1,28 @@
 ### MODULE IMPORTS ###
-from base import node
+from base import tag_node
+from helper import assemble
 
 ### LIBRARY IMPORTS ###
 import elementtree.ElementTree as et
 
-def Element(tag):
-    return elemtree(et.Element(tag))
+def Element(tag,**kwargs):
+    return elemtree(et.Element(tag),**kwargs)
 
-def to_string(node,pretty_print=False):
-    return et.tostring(node.node,pretty_print)
+def to_string(node):
+    return et.tostring(node.node)
 
 def from_string(xml_str):
     t = elemtree()
-    return t.from_string(xml_str)
+    return assemble(t,elemtree)
 
-class elemtree(node):
+class elemtree(tag_node):
     """An abstract XML API for elementetree"""
 
-    # def __repr__(self):
-#         try:
-#             return "<%s>" % self.tag
-#         except AttributeError:
-#             return "gXML instance(elemtree)"
+    def __repr__(self):
+        try:
+            return "<%s/>" % self.tag
+        except AttributeError:
+            return "gXML instance(elemtree)"
 
     tail = property( lambda obj: obj.node.tail )
 
@@ -29,6 +30,7 @@ class elemtree(node):
         """Parse a string."""
         self.node = et.fromstring(xml_str)
         
+        
         return self
     
     def parse(self,file_object):
@@ -37,31 +39,19 @@ class elemtree(node):
 
         self.node = t.getroot()
         
+        assemble(self,self.__class__)
+
         return self
     
     def get_child_nodes(self):
         """Return the child_nodes."""
 
-        #if they haven't changed since last time we asked for them
-        if not self._child_nodes_changed:
-            return self.children
-        
-        #if they have or if we've never asked for them before
         children = []
         #find them
         for child in self.node.getchildren():
-            children.append(elemtree(child,self))
+            children.append(child)
 
-        #save them
-        self.children = children
-        
-        #mark until dirtied
-        self._child_nodes_changed = False
-
-        return self.children
-
-    #a list of the child nodes
-    child_nodes = property(get_child_nodes)
+        return children
 
     keys = property( lambda obj: obj.node.keys )
     
@@ -69,10 +59,10 @@ class elemtree(node):
     tag = property( lambda obj: obj.node.tag )
 
     #get an attribute
-    get = property( lambda obj: obj.node.get )
+    get_attribute = property( lambda obj: obj.node.get )
 
     #set an attribute
-    set = property( lambda obj: obj.node.set )
+    set_attribute = property( lambda obj: obj.node.set )
 
     def remove_attr(self,attribute):
         """Remove an attribute."""
@@ -84,14 +74,10 @@ class elemtree(node):
     #get the nodes text
     text = property( lambda obj: obj.node.text , set_text)
 
-    def append(self,node):
+    def append_node(self,node):
         """Append a child node."""
         #append the node to the elementree instance
-        self.node.append(node.node)
-        #mark the child_nodes as dirty
-        self._child_nodes_changed = True
-
-        return self
+        self.node.append(node)
 
 if __name__ == '__main__':
     import pdb
