@@ -1,5 +1,6 @@
 import xml.dom.minidom
-from base import node
+from base import tag_node
+from helper import assemble
 import pdb
 
 def is_junk(node):
@@ -7,9 +8,9 @@ def is_junk(node):
     if node.nodeName == u'#text' or node.nodeName == u'#comment' or node.nodeName == u'#cdata-section':
         return True
 
-def Element(tag):
+def Element(tag,**kwargs):
     """Creates an element with given tag."""
-    return minidom(xml.dom.minidom.parseString("<%s/>"%tag).childNodes[0])
+    return minidom(xml.dom.minidom.parseString("<%s/>"%tag).childNodes[0],**kwargs)
 
 def to_string(node,pretty_print=False):
     """Turns an element tree into a string."""
@@ -22,7 +23,7 @@ def from_string(xml_str):
     t = minidom()
     return t.from_string(xml_str)
 
-class minidom(node):
+class minidom(tag_node):
     # def __repr__(self):
 #         try:
 #             return "<%s>" % self.node.nodeName
@@ -35,7 +36,7 @@ class minidom(node):
         """Parse a string."""
         self.node = xml.dom.minidom.parseString(xml_str).childNodes[0]
         
-        return self
+        return assemble(self,self.__class__)
 
     def parse(self,file_object):
         """Parse a file object."""
@@ -43,31 +44,19 @@ class minidom(node):
         #parse it
         self.node = xml.dom.minidom.parse(file_object).childNodes[0]
 
-        return self
+        return assemble(self,self.__class__)
     
     def get_child_nodes(self):
         """Returns the child nodes of an object."""
-        #if they haven't changed since last time
-        if not self._child_nodes_changed:
-            return self.children
-        
         #if they have or we've never asked for them before
         children = []
         #find them
         for child in self.node.childNodes:
             if not is_junk(child):
-                children.append(minidom(child,self))
+                children.append(child)
 
-        #save them
-        self.children = children
-
-        #mark false until dirtied
-        self._child_nodes_changed = False
-        
-        return self.children
+        return children
     
-    child_nodes = property(get_child_nodes)
-
     keys = property( lambda obj: obj.node.attributes.keys )
 
     def get_tag(self):
@@ -76,7 +65,7 @@ class minidom(node):
 
     tag = property(get_tag)
 
-    def get(self,attribute):
+    def get_attribute(self,attribute):
         """Get the value of an attribute."""
         val = self.node.getAttribute(attribute)
 
@@ -85,7 +74,7 @@ class minidom(node):
 
         return str(val)
 
-    def set(self,attribute,value):
+    def set_attribute(self,attribute,value):
         """Set the value of an attribute."""
         self.node.setAttribute(attribute,value)
 
@@ -133,14 +122,10 @@ class minidom(node):
         
     text = property(get_text,set_text)
 
-    def append(self,node):
+    def append_node(self,node):
         """Append a child node."""
         #append the child
-        self.node.appendChild(node.node)
-
-        #mark it as dirty
-        self._child_nodes_changed = True
-        
+        self.node.appendChild(node)        
 
 if __name__ == '__main__':
     import pdb
@@ -149,4 +134,3 @@ if __name__ == '__main__':
     t.parse('test.xml')
     
     pdb.set_trace()
-        
